<?php
/**
 * @file
 * Contains \Drupal\jw_player\JwPlayer7ConfigurationTest.
 */

namespace Drupal\jw_player\Tests;

use Drupal\Core\Entity\Entity\EntityViewDisplay;
use Drupal\field_ui\Tests\FieldUiTestTrait;
use Drupal\simpletest\WebTestBase;

/**
 * Tests configuration of a jw player 7 preset and creation of jw player content.
 *
 * @group jw_player
 */
class JwPlayer7ConfigurationTest extends WebTestBase {

  use FieldUiTestTrait;

  /**
   * Modules to enable.
   *
   * @var array
   */
  public static $modules = array(
    'node',
    'jw_player',
    'libraries',
    'file',
    'field',
    'field_ui',
    'block',
  );

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();
    // Create jw_player content type.
    $this->drupalCreateContentType(array('type' => 'jw_player', 'name' => 'JW content'));
    // Place the breadcrumb, tested in fieldUIAddNewField().
    $this->drupalPlaceBlock('system_breadcrumb_block');
  }

  /**
   * Tests the jw player creation.
   */
  public function testJwPlayerCreation() {

    $admin_user = $this->drupalCreateUser(array(
      'administer site configuration',
      'administer JW Player presets',
      'administer nodes',
      'create jw_player content',
      'administer content types',
      'administer node fields',
      'administer node display',
      'access administration pages',
    ));
    $this->drupalLogin($admin_user);

    // Add a random "Cloud-Hosted Account Token".
    $edit = [
      'cloud_player_library_url' => $token = 'https://content.jwplatform.com/libraries/' . $this->randomMachineName(8) . '.js',
      'jw_player_version' => 7,
    ];
    $this->drupalPostForm('admin/config/media/jw_player/settings', $edit, t('Save configuration'));
    // Create a jw player preset.
    $edit = array(
      'label' => 'Test preset',
      'id' => 'test_preset',
      'description' => 'Test preset description',
      'settings[width]' => 100,
      'settings[height]' => 100,
      'settings[advertising][client]' => 'vast',
      'settings[advertising][tag]' => 'www.example.com/vast',
      'settings[controlbar]' => 'bottom',
    );
    $this->drupalPostForm('admin/config/media/jw_player/add', $edit, t('Save'));
    $this->assertText('Saved the Test preset Preset.');
    // Make sure preset has correct values.
    $this->drupalGet('admin/config/media/jw_player/test_preset');
    $this->assertFieldByName('label', 'Test preset');
    $this->assertFieldByName('description', 'Test preset description');
    $this->assertNoField('settings[mode]');
    $this->assertNoField('settings[skin]');
    $this->assertFieldByName('settings[advertising][client]', 'vast');
    $this->assertFieldByName('settings[advertising][tag]', 'www.example.com/vast');
    $this->assertFieldByName('settings[controlbar]', 'bottom');

    // Create a JW player format file field in JW content type.
    static::fieldUIAddNewField('admin/structure/types/manage/jw_player', 'video', 'Video', 'file', array(), array('settings[file_extensions]' => 'mp4'));
    $this->drupalPostForm('admin/structure/types/manage/jw_player/display', array('fields[field_video][type]' => 'jwplayer_formatter'), t('Save'));
    $this->drupalPostAjaxForm(NULL, NULL, 'field_video_settings_edit');
    $this->drupalPostForm(NULL, NULL, t('Update'));
    $this->drupalPostForm(NULL, NULL, t('Save'));
    // Make sure JW preset is correct.
    $this->assertText('Preset: test_preset');
    $this->assertText('width: 100');
    $this->assertText('height: 100');
    // Make sure the formatter reports correct dependencies.
    /** @var \Drupal\Core\Entity\Entity\EntityViewDisplay $view_display */
    $view_display = EntityViewDisplay::load('node.jw_player.default');
    $this->assertTrue(in_array('jw_player.preset.test_preset', $view_display->getDependencies()['config']));

    // Create a 'video' file, which has .mp4 extension.
    $text = 'Trust me I\'m a video';
    file_put_contents('temporary://myVideo.mp4', $text);
    // Create video content from JW content type.
    $edit = array(
      'title[0][value]' => 'Test video',
      'files[field_video_0]' => drupal_realpath('temporary://myVideo.mp4'),
    );
    $this->drupalPostForm('node/add/jw_player', $edit, t('Save and publish'));
    $this->assertText('JW content Test video has been created.');

    $value = $this->xpath('//video/@id');
    $id = (string) $value[0]['id'];
    // Check the jw_player js.
    $this->assertRaw('jwplayer(\'' . $id . '\').setup( {"file":"' . file_create_url(\Drupal::token()->replace('public://[date:custom:Y]-[date:custom:m]/myVideo.mp4')) . '","width":100,"height":100,"controlbar":"bottom","advertising":{"client":"vast","tag":"www.example.com/vast"},"primary":"html5"})');
    // Make sure the hash is there.
    $this->assertTrue(preg_match('/jwplayer-[a-zA-Z0-9]{1,}$/', $id));
    // Check the library created because of cloud hosting.
    $this->assertRaw('<script src="' . $token . '"></script>');
  }

}
